package de.tudarmstadt.ke.sw.matching;


import java.io.File;
import java.net.URI;
import java.util.Enumeration;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Properties;

import org.semanticweb.owl.align.Alignment;
import org.semanticweb.owl.align.AlignmentException;
import org.semanticweb.owl.align.AlignmentProcess;
import org.semanticweb.owl.align.Cell;
import org.semanticweb.owl.align.Evaluator;

import com.hp.hpl.jena.ontology.OntClass;
import com.hp.hpl.jena.ontology.OntModel;
import com.hp.hpl.jena.rdf.model.ModelFactory;
import com.hp.hpl.jena.util.iterator.ExtendedIterator;

import fr.inrialpes.exmo.align.impl.BasicAlignment;
import fr.inrialpes.exmo.align.impl.BasicEvaluator;
import fr.inrialpes.exmo.align.impl.URIAlignment;
import fr.inrialpes.exmo.align.impl.eval.PRecEvaluator;
import fr.inrialpes.exmo.align.parser.AlignmentParser;
import fr.inrialpes.exmo.align.util.EvalAlign;

public class MyMatcher extends BasicAlignment implements AlignmentProcess {

	private URI uri1;
	private URI uri2;
	
	@Override
	public void init(Object arg0, Object arg1) throws AlignmentException {
		uri1 = (URI) arg0;
		uri2 = (URI) arg1;
	}
	
	@Override
	public void align(Alignment alignment, Properties props)
			throws AlignmentException {

		OntModel onto1 = ModelFactory.createOntologyModel();
		onto1.read(uri1.toString());
		
		OntModel onto2 = ModelFactory.createOntologyModel();
		onto2.read(uri2.toString());
		
		// key: name
		// value: uri
		HashMap<String,String> classNames1 = new HashMap<String,String>();
		
		ExtendedIterator<OntClass> classes1 = onto1.listClasses();
		while(classes1.hasNext()) {
			OntClass ontClass = classes1.next();
			if(ontClass.getLocalName()!=null)
				classNames1.put(ontClass.getLocalName(),ontClass.getURI());
		}
		
		ExtendedIterator<OntClass> classes2 = onto2.listClasses();
		while(classes2.hasNext()) {
			OntClass ontClass = classes2.next();
			if(classNames1.containsKey(ontClass.getLocalName())) {
				alignment.addAlignCell(URI.create(classNames1.get(ontClass.getLocalName())), URI.create(ontClass.getURI()));
			}
		}
		
	}
	
	public static void main(String[] args) throws AlignmentException {
		String testCase = "103";
		
		MyMatcher matcher = new MyMatcher();
		matcher.init(new File("benchmarks/101/onto.rdf").toURI(),new File("benchmarks/"+testCase+"/onto.rdf").toURI());
		Alignment foundalign = new URIAlignment();
		matcher.align(foundalign, null);

		AlignmentParser aparser = new AlignmentParser(0);
		Alignment refalign = aparser.parse(new File("benchmarks/"+testCase+"/refalign.rdf").toURI());
		
		PRecEvaluator eval = new PRecEvaluator(refalign, foundalign);
		eval.eval(null);
		System.out.println(eval.getResults());
	}
}
